binderclasses
open | /demo/kss_binder_classes.html |
click | alpha1 |
waitForTextPresent | [50] |
click | alpha1 |
waitForTextPresent | [50][51] |
click | beta1 |
waitForTextPresent | [50][51][100] |
click | beta2 |
waitForTextPresent | [50][51][100][101] |
click | beta1 |
waitForTextPresent | [50][51][100][101][102] |
click | beta1 |
waitForTextPresent | [50][51][100][101][102][103] |
click | beta2 |
verifyTextPresent | [50][51][100][101][102][103][104] |
click | alpha1 |
waitForTextPresent | [50][51][100][101][102][103][104][52] |